OAuthProvider class

Constructors

OAuthProvider({required String name, required String discoveryUrl, required String clientId, required String redirectUrl, List<String> scopes = const ['openid', 'profile', 'email']})
const

Properties

clientId String
final
discoveryUrl String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
redirectUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited