OAuthService class

Constructors

OAuthService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAuthorizationUrl(OAuthProvider provider) Future<String>
handleRedirect(String url, OAuthProvider provider) Future<AuthorizationTokenResponse?>
logout(OAuthProvider provider, String idTokenHint) Future<bool>
performOAuthFlow(BuildContext context, OAuthProvider provider, {Widget? loadingWidget, Color? backgroundColor}) Future<AuthorizationTokenResponse?>